@@ -704,91 +704,3 @@ addDate <- function(date, periods, freq)
   }
 
 
-############################################################
-
-#  Utility function for time series noise   <<<<<<<<<<
-
-############################################################
-
-makeTSnoise <- function(sampleT,p,lags,noise=NULL, rng=NULL,
-                        SIGMA=NULL, sd=1, noise.model=NULL,
-                        noise.baseline=0,
-                        tf=NULL, start=NULL,frequency=NULL)
- {# CAUTION: changes here can affect historical comparisons.
-  # noise.baseline is added to noise. It should be either a scalar, a matrix of
-  #   the same dimension as noise (or noise generated by noise.model), or a
-  #   vector of length equal to the dimension of the noise process (which will
-  #   be replicated for all periods.)
- if(!require("setRNG")) stop("This function requires the setRNG package.")
- if(is.null(rng)) rng <- setRNG() # returns setting so don't skip if NULL
- else        {old.rng <- setRNG(rng);  on.exit(setRNG(old.rng))  }
-
-  if ( (!is.null(noise)) & (!is.null(noise.model)) )
-    stop("noise and noise.model cannot both be specified.")
-
-  if(!is.null(noise.baseline) && is.matrix(noise.baseline) &&
-    (sampleT < dim(noise.baseline)[1]))
-      {warning("sampleT (and start date) for noise adjusted to match noise.baseline")
-       sampleT <- dim(noise.baseline)[1]
-      }
-
- # Note: noise is added to initial conditions.
- if (!is.null(noise.model))
-   {if(!require("dse1"))
-       stop("Generating noise with a TSmodel requires the dse1 package.")
-    noise <- outputData(simulate(noise.model, sampleT=sampleT+lags))
-    noise <- list(w0=noise[1:lags,,drop=FALSE], w=noise[lags+seq(sampleT),,drop=FALSE])
-   }
-  if (is.null(noise)) {
-    w0 <-matrix(NA,lags,p)
-    w <- matrix(NA,sampleT,p)
-    if (!is.null(SIGMA)) {
-        if(length(SIGMA) == 1) SIGMA <- diag(SIGMA, p)
-	W <- t(chol(SIGMA))
-        w <- t(W %*% t(matrix(rnorm((lags+sampleT)*p),(lags+sampleT),p)))
-	w0 <- w[1:lags,]
-	w  <- w[-c(1:lags),]
-        }
-    else {
-       if (length(sd)==1) sd <-rep(sd,p)
-       for (i in 1:p)
-         {w0[,i] <- rnorm(lags,sd=sd[i])
-          w[,i]  <- rnorm(sampleT,sd=sd[i])
-         }
-       }
-    noise <- list(w=w, w0=w0)
-    }
-  else {
-     if (is.null(noise$w0) || is.null(noise$w) )
-       stop("supplied noise structure is not correct.")
-     }
-       
-  if(!is.null(noise.baseline))
-     {if (is.vector(noise.baseline))
-        {if(length(noise.baseline)==1) noise$w <- noise$w + noise.baseline
-         else if(length(noise.baseline)==1)
-           noise$w <-noise$w + t(array(noise.baseline, rev(dim(noise$w))))
-         else stop("noise.baseline vector is not correct length.")
-        }
-      else  noise$w <- noise$w + noise.baseline
-     }
-
-  if(!is.null(tf)) tframe(noise$w) <- tf
-  else if(!is.null(start))
-      {if (is.null(frequency))
-         {frequency <- 1
-          warning("start set but frequency not specified. Using frequency=1.")
-         }
-       else noise$w <-tframed(noise$w, list(start=start, frequency=frequency))
-       if (is.tframed(noise.baseline) &&
-           testEqual(tframe(noise.baseline),tframe(noise$w)))
-           {warning("tframe of noise set to tframe of noise.baseline.")
-            tframe(noise$w )<-tframe(noise.baseline)
-            if(!all(dimnames(noise$w)[[2]] == dimnames(noise.baseline)[[2]]))
-              warning("noise names and noise.baseline names do not correspond.")
-           }
-      }
-  append(noise, list(sampleT=sampleT, rng=rng,
-     SIGMA=SIGMA, sd=sd, noise.model=noise.model,version=as.vector(version)))
- }
-
